==> haskell-splitmix-0.0.3-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-splitmix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: splitmix
version: 0.0.3
id: splitmix-0.0.3-FghYurqzSDK8LuM9E0TBHw
key: splitmix-0.0.3-FghYurqzSDK8LuM9E0TBHw
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis: Fast Splittable PRNG
description:
    Pure Haskell implementation of SplitMix described in
    .
    Guy L. Steele, Jr., Doug Lea, and Christine H. Flood. 2014.
    Fast splittable pseudorandom number generators. In Proceedings
    of the 2014 ACM International Conference on Object Oriented
    Programming Systems Languages & Applications (OOPSLA '\''14). ACM,
    New York, NY, USA, 453-472. DOI:
    <https://doi.org/10.1145/2660193.2660195>
    .
    The paper describes a new algorithm /SplitMix/ for /splittable/
    pseudorandom number generator that is quite fast: 9 64 bit arithmetic/logical
    operations per 64 bits generated.
    .
    /SplitMix/ is tested with two standard statistical test suites (DieHarder and
    TestU01, this implementation only using the former) and it appears to be
    adequate for "everyday" use, such as Monte Carlo algorithms and randomized
    data structures where speed is important.
    .
    In particular, it __should not be used for cryptographic or security applications__,
    because generated sequences of pseudorandom values are too predictable
    (the mixing functions are easily inverted, and two successive outputs
    suffice to reconstruct the internal state).
category: System, Random
abi: 40bf0ef40c21e45d07e3d9aafbb375f2
exposed: True
exposed-modules:
    System.Random.SplitMix System.Random.SplitMix32
hidden-modules: Data.Bits.Compat
import-dirs: /usr/lib/ghc-8.6.5/site-local/splitmix-0.0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/splitmix-0.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/splitmix-0.0.3
hs-libraries: HSsplitmix-0.0.3-FghYurqzSDK8LuM9E0TBHw
depends:
    base-4.12.0.0 deepseq-1.4.4.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
    time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-splitmix/html/splitmix.haddock
haddock-html: /usr/share/doc/haskell-splitmix/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-splitmix-0.0.3-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-splitmix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: splitmix
version: 0.0.3
id: splitmix-0.0.3-1OmyOU5VDgdEtZ48UIhlbs
key: splitmix-0.0.3-1OmyOU5VDgdEtZ48UIhlbs
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis: Fast Splittable PRNG
description:
    Pure Haskell implementation of SplitMix described in
    .
    Guy L. Steele, Jr., Doug Lea, and Christine H. Flood. 2014.
    Fast splittable pseudorandom number generators. In Proceedings
    of the 2014 ACM International Conference on Object Oriented
    Programming Systems Languages & Applications (OOPSLA '\''14). ACM,
    New York, NY, USA, 453-472. DOI:
    <https://doi.org/10.1145/2660193.2660195>
    .
    The paper describes a new algorithm /SplitMix/ for /splittable/
    pseudorandom number generator that is quite fast: 9 64 bit arithmetic/logical
    operations per 64 bits generated.
    .
    /SplitMix/ is tested with two standard statistical test suites (DieHarder and
    TestU01, this implementation only using the former) and it appears to be
    adequate for "everyday" use, such as Monte Carlo algorithms and randomized
    data structures where speed is important.
    .
    In particular, it __should not be used for cryptographic or security applications__,
    because generated sequences of pseudorandom values are too predictable
    (the mixing functions are easily inverted, and two successive outputs
    suffice to reconstruct the internal state).
category: System, Random
abi: 07dde95e0325760c02b882a1fe738197
exposed: True
exposed-modules:
    System.Random.SplitMix System.Random.SplitMix32
hidden-modules: Data.Bits.Compat
import-dirs: /usr/lib/ghc-8.6.5/site-local/splitmix-0.0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/splitmix-0.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/splitmix-0.0.3
hs-libraries: HSsplitmix-0.0.3-1OmyOU5VDgdEtZ48UIhlbs
depends:
    base-4.12.0.0 deepseq-1.4.4.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
    time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-splitmix/html/splitmix.haddock
haddock-html: /usr/share/doc/haskell-splitmix/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
